# netbox_awx_plugin/tests/test_models.py

from django.test import TestCase
from netbox_awx_plugin.models import AWX, AWXInventory
from django.urls import reverse


class AWXModelTestCase(TestCase):

    def setUp(self):
        self.awx_instance = AWX.objects.create(
            name="Test AWX",
            url="http://awx.example.com",
            token="dummy-token"
        )

    def test_awx_str(self):
        """Test the string representation of the AWX model."""
        self.assertEqual(str(self.awx_instance), "Test AWX")

    def test_awx_get_absolute_url(self):
        """Test that get_absolute_url returns the correct URL."""
        url = self.awx_instance.get_absolute_url()
        expected_url = reverse("plugins:netbox_awx_plugin:awx", args=[self.awx_instance.pk])
        self.assertEqual(url, expected_url)

    def test_awx_get_headers(self):
        """Test that get_headers returns the correct headers."""
        headers = self.awx_instance.get_headers()
        expected_headers = {
            "Authorization": "Bearer dummy-token",
            "Content-type": "application/json",
        }
        self.assertEqual(headers, expected_headers)


class AWXInventoryModelTestCase(TestCase):

    def setUp(self):
        self.awx_instance = AWX.objects.create(
            name="Test AWX",
            url="http://awx.example.com",
            token="dummy-token"
        )
        self.inventory = AWXInventory.objects.create(
            awx=self.awx_instance,
            inventory_id=1,
            enabled=True
        )

    def test_inventory_get_absolute_url(self):
        """Test that get_absolute_url returns the correct URL."""
        url = self.inventory.get_absolute_url()
        expected_url = reverse("plugins:netbox_awx_plugin:awxinventory", args=[self.inventory.pk])
        self.assertEqual(url, expected_url)
